from django.db import models


class ForbiddenIP(models.Model):
    ip = models.CharField(max_length=18)
    reason = models.CharField(max_length=200, null=True)

    class Meta:
        verbose_name = verbose_name_plural = 'forbidden_ip'

    def __str__(self):
        return f'ForbiddenIP:{self.ip}'



from django.http import HttpResponseForbidden
from django.utils.deprecation import MiddlewareMixin

from .models import ForbiddenIP


class IPInterceptorMiddleware(MiddlewareMixin):
    def __init__(self, get_reqponse):
        self.get_response = get_reqponse

    def validate_ip(self, remote_ip):
        if ForbiddenIP.objects.filter(ip=remote_ip).count():
            return False
        return True

    def process_request(self, request):
        ip = request.META.get('REMOTE_ADDR')
        if not self.validate_ip(ip):
            return HttpResponseForbidden('')



from setuptools import find_packages, setup

with open('README.md', encoding='utf8') as f:
    long_description = f.read()

setup(
    name='django-forbidden-ip',
    version=0.1,
    description='IP forbidding utilities for Django2.0',
    long_description=long_description,
    author='Jason Qiao',
    author_email='jasonqiao36@gmail.com',
    python_requires='>=3.6.0',
    url='https://github.com/jasonqiao36/django-forbidden-ip',
    packages=find_packages(),
    install_requires=[
        'Django>=2.0',
    ],
    include_package_data=True,
    zip_safe=False,
    license='MIT',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Framework :: Django',
        'Environment :: Plugins',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.6',
    ],
)